@@ -2,4 +2,4 @@
 # Must not run any test, just run the user
 if __name__ == "__main__":
     import template
-    template.{{ targetMethod }}
+    template.{{ targetMethod }} #TODO define your own args 
