@@ -12,8 +12,9 @@ if __name__ == "__main__":
 
     # Complete code with more test
     # Only one is not enough
-    userValue = template.{{ targetMethod }}
-    expectedValue = success.{{ targetMethod }}
+    userValue = template.{{ targetMethod }} #TODO define your own args
+    expectedValue = success.{{ targetMethod }} #TODO define your own args
+
     if userValue != expectedValue:
         print("Wrong value")
         print("> expected: " + str(expectedValue))
